=======================================================
HiGlass Python
=======================================================

`higlass-python <https://github.com/higlass/higlass-python>`_ is an interactive Python
interface for `HiGlass <https://higlass.io>`_. It provides functionality for composing
and visualizing view configurations. See the `Getting Started section </getting_started.html>`_
for an overview of the provided functionality.

.. toctree::
    :hidden:
    :glob:

    getting_started
    examples
    python_api
